/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.doc;

import freemarker.template.*;

/**
 * A simple class representing a single tab in the web site's table of contents
 * frame navigation.
 *
 * @version $Id: TabItem.java 1003 2004-10-16 14:54:58Z run2000 $
 */
public class TabItem implements TemplateHashModel {
    private final TemplateScalarModel tabName;
    private final TemplateScalarModel tabLink;

    /** Creates new TabItem */
    public TabItem( String name, String link ) {
        tabName = new FastScalar( name );
        tabLink = new FastScalar( link );
    }

    /**
     * Gets a {@link freemarker.template.TemplateModel} from the hash.
     *
     * @param key the name by which the <code>TemplateModel</code>
     * is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     * or <code>null</code> if not found.
     */
    public TemplateModel get(String key) throws TemplateModelException {
        if( "name".equals(key)) {
            return tabName;
        } else if( "link".equals(key)) {
            return tabLink;
        } else {
            return null;
        }
    }

    /**
     * Is this model empty?
     *
     * @return <code>true</code> if this object is empty, otherwise
     * <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

}
