/*
 * ====================================================================
 *
 * Copyright (c) 2000 Attila Szegedi.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes the Expose library
 *        (http://www.szegedi.org/expose)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "Expose" and "Attila Szegedi" must not be used to endorse
 *    or promote products derived from this software without prior written
 *    permission. For written permission, please contact expose@szegedi.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 */

package freemarker.ext.beans;

import freemarker.template.*;
import java.util.*;

/**
 * <p>A class that adds {@link TemplateListModel2} functionality to the
 * {@link Iterator} interface implementers.</p>
 *
 * <p>Using the model as a list model is <em>NOT</em> thread-safe, as
 * iterators are inherently not thread-safe.</p>
 *
 * @author Attila Szegedi, attila@szegedi.org
 * @version $Id: IteratorModel.java 1163 2005-10-09 10:47:15Z run2000 $
 * @deprecated this class is deprecated in favour of the classes in the
 * {@link freemarker.ext.beans2} package
 */
public final class IteratorModel extends ObjectModel implements TemplateListModel2
{
	private Collection underlyingCollection;

    /** Serialization UUID for this class. */
    private static final long serialVersionUID = -486444129621340252L;

	/**
	 * Creates a new model that wraps the specified iterator object.
	 * @param iterator the iterator object to wrap into a model.
	 */
	public IteratorModel(Iterator iterator)
	{
		super(iterator);
	}

	IteratorModel(Collection underlyingCollection)
	{
		this(underlyingCollection.iterator());
		this.underlyingCollection = underlyingCollection;
	}

	/**
	 * Returns a model wrapping the specified iterator object. It always returns a new
	 * object, as Iterators are considered short-lived and caching them would have little
	 * sense.
	 * @return the model for the iterator
	 */
	public static final IteratorModel getInstance(Iterator object)
	{
		return new IteratorModel(object);
	}

	/**
	 * Returns the type of this object (which is TYPE_ITERATOR)
	 */
	public @Override ModelType getType()
	{
		return ModelType.TYPE_ITERATOR;
	}

    /**
     * Returns true if the iterator is null or the iterator has no elements
     * remaining, otherwise false.
     */
    public @Override boolean isEmpty()
    {
        return object == null || !(((Iterator)object).hasNext());
    }

    /**
     * Retrive an iterator for this object.
     *
     * @return a <code>TemplateIteratorModel</code> wrapping the underlying
     * <code>java.util.Iterator</code> implementation
     */
    public TemplateIteratorModel templateIterator() throws TemplateModelException {
        return new IteratorModelImpl( (Iterator)object );
    }

    /**
     * Release the underlying iterator. The iterator can only be called once.
     *
     * @param iterator the wrapper for the iterator to be released
     */
    public void releaseIterator( TemplateIteratorModel iterator ) {
        if( underlyingCollection == null ) {
            object = null;
        } else {
            object = underlyingCollection.iterator();
        }
    }
}
