/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.ext.beans;

import java.util.Iterator;

import freemarker.template.TemplateIteratorModel;
import freemarker.template.TemplateModel;

/**
 * An implementation of the iterator model. Any objects returned by the
 * iterator are wrapped by {@link BeansWrapper} before being returned to
 * the client. Used by {@link IteratorModel} and {@link CollectionModel}.
 *
 * @version $Id: IteratorModelImpl.java 1163 2005-10-09 10:47:15Z run2000 $
 * @deprecated this class is deprecated in favour of the classes in the
 * {@link freemarker.ext.beans2} package
 */
class IteratorModelImpl implements TemplateIteratorModel {
    private Iterator iterator;

    /**
     * Takes an iterator object to be iterated over. Any objects returned
     * by the iterator will be wrapped by {@link BeansWrapper} before being
     * returned to the client.
     *
     * @param iterator the iterator to iterate over
     */
    public IteratorModelImpl( Iterator iterator ) {
        this.iterator = iterator;
    }

    /**
     * Calls {@link Iterator#hasNext()}.
     */
    public boolean hasNext()
    {
        return iterator.hasNext();
    }

    /**
     * Calls {@link Iterator#next()}.
     */
    public TemplateModel next()
    {
        return BeansWrapper.wrap(iterator.next());
    }

    /**
     * Returns true if the iterator is null or the iterator has no elements
     * remaining, otherwise false.
     */
    public boolean isEmpty()
    {
        return iterator == null || !(iterator.hasNext());
    }
}
