/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.ext.beans;

import java.util.List;

import freemarker.template.TemplateIndexedModel;
import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;

/**
 * <p>A special case of {@link CollectionModel} that implements
 * {@link freemarker.template.TemplateIndexedModel} to allow gets using
 * numbered indexes.</p>
 *
 * @author Nicholas Cull
 * @version $Id: ListModel.java 1163 2005-10-09 10:47:15Z run2000 $
 * @deprecated this class is deprecated in favour of the classes in the
 * {@link freemarker.ext.beans2} package
 */
public final class ListModel extends CollectionModel implements TemplateIndexedModel {

    /** Serialization UUID for this class. */
    private static final long serialVersionUID = 4752161757569839694L;

    /**
     * Creates a new model that wraps the specified collection object.
     * @param list the list object to wrap into a model.
     */
    public ListModel(List list)
    {
        super(list);
    }

    /**
     * Returns a model wrapping the specified list object. If there is already
     * a cached model instance for this list, returns the cached model instance.
     * Models are cached using <code>WeakReference</code> objects. The caching can be turned
     * off by setting the <kbd>expose.reflection.nocache</kbd> system property to
     * true. In this case calling this method is equivalent to constructing a new model.
     * @param object the list to wrap into a model.
     * @return the model for the list
     */
    public static final CollectionModel getInstance(List object)
    {
        if(noCache)
            return new ListModel(object);

        ListModel model = (ListModel)lookup(object);
        if(model == null)
        {
            model = new ListModel(object);
            register(model, object);
        }
        return model;
    }

    /**
     * Returns the type of this object (which is TYPE_COLLECTION)
     */
    public @Override ModelType getType()
    {
        return ModelType.TYPE_LIST;
    }

    /**
     * Get the object at the specified index. Returns a suitable TemplateModel
     * for the underlying value.
     *
     * @param index the index of object within the list
     * @return the object at the specified index
     * @throws TemplateModelException there was a problem with the
     */
    public TemplateModel getAtIndex( long index ) throws TemplateModelException {
        try {
            return BeansWrapper.wrap(((List)object).get( (int)index ));
        } catch( IndexOutOfBoundsException e ) {
            throw new TemplateModelException( "Index into list is out of bounds", e );
        }
    }
}
