/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans;

import freemarker.template.TemplateNumberModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateScalarModel;
import freemarker.template.TemplateObjectModel;

import java.io.Serializable;

/**
 * Holds subclasses of <code>Number</code> for evaluation as
 * <code>TemplateNumberModel</code> or unwrapped as an object.
 * We also implement <code>TemplateScalarModel</code> so that
 * floats or doubles are printed with full precision.
 *
 * @author Nicholas Cull
 * @version $Id: SimpleNumberModel.java 1163 2005-10-09 10:47:15Z run2000 $
 * @deprecated this class is deprecated in favour of the classes in the
 * {@link freemarker.ext.beans2} package
 */
public class SimpleNumberModel implements TemplateNumberModel,
        TemplateScalarModel, TemplateObjectModel, Serializable {

    /** The number wrapped by this model. */
    private Number number;

    /** Serialization UUID for this class. */
    private static final long serialVersionUID = -2327048511588374224L;

    /**
     * Constructor that takes the <code>Number</code> object to be wrapped.
     *
     * @param number the number to be wrapped
     */
    public SimpleNumberModel( Number number ) {
        this.number = number;
    }

    /**
     * Retrieve the underlying value as a <code>long</code>. Numbers that
     * use decimal places will be rounded appropriately.
     *
     * @return a long value representing the underlying number
     * @throws TemplateModelException
     */
    public long getAsNumber() throws TemplateModelException {
        return number.longValue();
    }

    /**
     * Retrieve the underlying value as a <code>String</code>. This preserves
     * any decimal places held in the underlying object.
     *
     * @return a String representation of the underlying number
     * @throws TemplateModelException
     */
    public String getAsString() throws TemplateModelException {
        return number.toString();
    }

    /**
     * Is there an underlying number in this model?
     *
     * @return <code>true</code> if there is a Number object present, otherwise
     * <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return number == null;
    }

    /**
     * Retrieve the underlying object for object unwrapping purposes.
     * @return the underlying <code>Number</code> object
     */
    public Object getAsObject() throws TemplateModelException {
        return number;
    }
}
