/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import java.util.*;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.beans.PropertyDescriptor;

/**
 * @author Nicholas Cull
 * @version $Id: ClassFeatures.java 1111 2005-09-09 11:37:18Z run2000 $
 * @since 1.9
 */
public class ClassFeatures<T> implements Features<T> {
    private String className;
    private Map<String, List<Method>> methods;
    private Map<String, Field> fields;
    private T[] enumValues;

    public ClassFeatures( Class<T> clazz ) {
        className = clazz.getName();
        Field[] fds = clazz.getFields();

        fields = new HashMap<String, Field>();
        for( int i = 0; i < fds.length; i++ ) {
            Field field = fds[ i ];
            fields.put( field.getName(), field );
        }

        enumValues = clazz.getEnumConstants();

        Method[] mds = clazz.getMethods();

        methods = new HashMap<String, List<Method>>();
        for( int i = 0; i < mds.length; i++ ) {
            Method m = mds[ i ];
            String name = m.getName();
            List<Method> methodList = methods.get( name );
            if( methodList == null ) {
                methodList = new ArrayList<Method>();
                methods.put( name, methodList );
            }
            methodList.add( m );
        }

        MethodComparator comparator = new MethodComparator();

        for( Map.Entry<String,List<Method>> entry : methods.entrySet() ) {
            //noinspection CollectionDeclaredAsConcreteClass
            ArrayList<Method> list = (ArrayList<Method>)entry.getValue();
            if( list.size() > 1 ) {
                Collections.sort(list, comparator);
            }
            list.trimToSize();
        }
    }

    public List<Method> getMethods( String name ) {
        return methods.get( name );
    }

    public PropertyDescriptor getProperty( String name ) {
        return null;
    }

    public Field getField( String name ) {
        return fields.get( name );
    }

    public T[] getEnumValues() {
        return enumValues;
    }

    /**
     * Returns a string representation of the object.
     *
     * @return a string representation of the object.
     */
    public String toString() {
        return "Features of " + className + " class: " + methods.size() +
                " unique method names, " +
                (enumValues == null ? "no" : Integer.toString( enumValues.length )) +
                " enums, " + fields.size() + " fields.";
    }
}
