/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import java.util.List;
import java.util.ArrayList;
import java.lang.reflect.Array;

import freemarker.template.TemplateModel;
import freemarker.template.TemplateListModel;
import freemarker.template.TemplateListModel2;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateIteratorModel;

/**
 * Returns an array of the specified type for a given list model.
 *
 * @author Nicholas Cull
 * @version $Id: ConvertToArray.java 1100 2005-09-07 13:31:21Z run2000 $
 * @since 1.9
 */
public class ConvertToArray implements Converter {

    private Class<?> clazz;

    public ConvertToArray( Class<?> clazz ) {
        this.clazz = clazz;
    }

    public Object convert( TemplateModel model )
            throws ClassCastException, NullPointerException, TemplateModelException {

        List<Object> result;

        if( model instanceof TemplateListModel ) {
            TemplateListModel listModel = (TemplateListModel) model;
            if( listModel.isEmpty() ) {
                return null;
            }
            result = new ArrayList<Object>();
            if( ! listModel.isRewound() ) {
                listModel.rewind();
            }
            while( listModel.hasNext() ) {
                TemplateModel item = listModel.next();
                result.add( Unwrapper.unwrap( item, clazz ));
            }
        } else {
            TemplateListModel2 listModel = (TemplateListModel2) model;
            if( listModel.isEmpty() ) {
                return null;
            }
            result = new ArrayList<Object>();
            TemplateIteratorModel iterator = listModel.templateIterator();
            while( iterator.hasNext() ) {
                TemplateModel item = iterator.next();
                result.add( Unwrapper.unwrap( item, clazz ));
            }
        }
        Object object = Array.newInstance( clazz, result.size() );
        Object[] array = (Object[])object;
        return result.toArray(array);
    }

    public boolean converts( TemplateModel model, Class<?> target ) {

        if( !( model instanceof TemplateListModel ) && !( model instanceof TemplateListModel2 )) {
            return false;
        }

        if(( target == null ) || ( ! target.isArray() )) {
            return false;
        }

        Class<?> componentType = target.getComponentType();
        if (! componentType.isAssignableFrom( clazz )) {
            return false;
        }

        // Peek at the first item in the list. This should tell us
        // whether we can convert the model in practice. Assumes that all
        // items in the list are of the same type.
        try {
            if( model instanceof TemplateListModel ) {
                TemplateListModel listModel = (TemplateListModel) model;
                if( ! listModel.isRewound() ) {
                    listModel.rewind();
                }
                if( listModel.hasNext() ) {
                    TemplateModel listItem = listModel.next();
                    return( Unwrapper.getConverter( listItem, clazz ) != null );
                }
            } else {
                TemplateListModel2 listModel = (TemplateListModel2) model;
                TemplateIteratorModel iterator = listModel.templateIterator();
                if( iterator.hasNext() ) {
                    TemplateModel listItem = iterator.next();
                    return( Unwrapper.getConverter( listItem, clazz ) != null );
                }
            }
        } catch( TemplateModelException e ) {
            return false;
        }

        // An empty list should be convertible
        return true;
    }
}
