/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import java.util.List;
import java.util.Vector;

import freemarker.template.TemplateModel;
import freemarker.template.TemplateListModel;
import freemarker.template.TemplateListModel2;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateIteratorModel;

/**
 * @author Nicholas Cull
 * @version $Id: ConvertToVector.java 1100 2005-09-07 13:31:21Z run2000 $
 */
public class ConvertToVector implements Converter {

    private static final ConvertToVector instance = new ConvertToVector();

    private ConvertToVector() {
    }

    public static ConvertToVector getInstance() {
        return instance;
    }

    public Object convert( TemplateModel model )
            throws ClassCastException, NullPointerException, TemplateModelException {

        if( model instanceof TemplateListModel ) {
            TemplateListModel listModel = (TemplateListModel) model;
            if( listModel.isEmpty() ) {
                return null;
            }
            List<Object> result = new Vector<Object>();
            if( ! listModel.isRewound() ) {
                listModel.rewind();
            }
            while( listModel.hasNext() ) {
                TemplateModel item = listModel.next();
                result.add( Unwrapper.defaultUnwrap( item ));
            }
            return result;
        } else {
            TemplateListModel2 listModel = (TemplateListModel2) model;
            if( listModel.isEmpty() ) {
                return null;
            }
            List<Object> result = new Vector<Object>();
            TemplateIteratorModel iterator = listModel.templateIterator();
            while( iterator.hasNext() ) {
                TemplateModel item = iterator.next();
                result.add( Unwrapper.defaultUnwrap( item ));
            }
            return result;
        }
    }

    public boolean converts( TemplateModel model, Class<?> target ) {

        if(!( model instanceof TemplateListModel ) && !( model instanceof TemplateListModel2 )) {
            return false;
        }

        return ( target != null ) && (target.isAssignableFrom( Vector.class ));
    }
}
