/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;

/**
 * An interface for classes implementing a conversion from a given
 * TemplateModel to a known Java object. Conversions should be context free,
 * and implementing classes should be flywheel classes, ie. not carrying
 * any internal state between calls. They may also be singletons.
 *
 * @author Nicholas Cull
 * @version $Id: Converter.java 1100 2005-09-07 13:31:21Z run2000 $
 * @since 1.9
 */
public interface Converter {

    Object convert( TemplateModel model ) throws IllegalArgumentException,
            NullPointerException, TemplateModelException;

    boolean converts( TemplateModel model, Class<?> target );
}
