/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateListModel2;
import freemarker.template.TemplateIteratorModel;
import freemarker.template.TemplateModelException;

import java.beans.IntrospectionException;
import java.io.Serializable;

/**
 * @author Nicholas Cull
 * @version $Id: EnumWrapper.java 1164 2005-10-09 11:57:04Z run2000 $
 * @since 1.9
 */
public class EnumWrapper<T extends Enum> extends BeanWrapper<T>
        implements TemplateListModel2, Serializable {

    /** Serialization UUID for this class */
    private static final long serialVersionUID = 885041368544649423L;

    public EnumWrapper() {
    }

    public EnumWrapper(T t) {
        super(t);
    }

    /**
     * Retrieves an iterator to iterate over the elements of the enum.
     *
     * @return an iterator to iterate over the current enum elements
     * @throws freemarker.template.TemplateModelException
     *          the next item in the list can't be
     *          retrieved, or no next item exists.
     */
    public TemplateIteratorModel templateIterator() throws TemplateModelException {
        try {
            Features<T> f = Wrapper.getObjectFeatures( object );
            return new EnumIterator<T>( f.getEnumValues() );
        } catch (IntrospectionException e) {
            throw new TemplateModelException( e.getMessage(), e );
        }
    }

    /**
     * <p>Returns the used iterator to the list model.</p>
     *
     * @param iterator the iterator to be returned
     */
    public void releaseIterator(TemplateIteratorModel iterator) {
        // Do nothing
    }

}
