/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateIteratorModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateModel;

import java.util.Iterator;
import java.io.Serializable;

/**
 * @author Nicholas Cull
 * @version $Id: IteratorWrapper.java 1164 2005-10-09 11:57:04Z run2000 $
 * @since 1.9
 */
public class IteratorWrapper<T extends Iterator> extends BeanWrapper<T>
        implements TemplateIteratorModel, Serializable {

    /** Serialization UUID for this class */
    private static final long serialVersionUID = -4482207604747105760L;

    public IteratorWrapper() {
    }

    public IteratorWrapper( T iterator ) {
        this.object = iterator;
    }

    /**
     * Is the object empty?
     *
     * @return <code>true</code> if this object is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return object == null;
    }

    /**
     * Do we have another item in the list?
     *
     * @return <code>true</code> if there are more items to be iterated over,
     *         otherwise <code>false</code>
     * @throws freemarker.template.TemplateModelException
     *          there was a problem determining the
     *          next item in the list
     */
    public boolean hasNext() throws TemplateModelException {
        return object.hasNext();
    }

    /**
     * Retrieve the next item in the list. The item will be a <code>TemplateModel</code>
     * containing the underlying value.
     *
     * @return the next item in the list
     * @throws freemarker.template.TemplateModelException
     *          the next item couldn't be retrieved,
     *          or we're at the end of the list
     */
    public TemplateModel next() throws TemplateModelException {
        Object next = this.object.next();
        return Wrapper.wrap( next );
    }
}
