/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateModelException;
import freemarker.template.TemplateModel;
import freemarker.template.TemplateWriteableIteratorModel;

import java.util.ListIterator;
import java.io.Serializable;

/**
 * @author Nicholas Cull
 * @version $Id: ListIteratorWrapper.java 1164 2005-10-09 11:57:04Z run2000 $
 * @since 1.9
 */
public class ListIteratorWrapper<T extends ListIterator> extends IteratorWrapper<T>
        implements TemplateWriteableIteratorModel, Serializable {

    /** Serialization UUID for this class */
    private static final long serialVersionUID = 3446935810442948171L;

    public ListIteratorWrapper() {
    }

    public ListIteratorWrapper( T iterator ) {
        this.object = iterator;
    }

    /**
     * Inserts the specified element into the list. The element is inserted
     * immediately before the next element that would be returned by next, if any.
     *
     * @param model the model to insert into the list
     * @throws freemarker.template.TemplateModelException
     *          the model could not be assigned
     *          to the list
     */
    public void set( TemplateModel model ) throws TemplateModelException {
        Object object = Unwrapper.defaultUnwrap( model );
        try {
            this.object.set( object );
        } catch( UnsupportedOperationException e ) {
            throw new TemplateModelException( e.getMessage(), e );
        } catch( ClassCastException e ) {
            throw new TemplateModelException( e.getMessage(), e );
        } catch( IllegalArgumentException e ) {
            throw new TemplateModelException( e.getMessage(), e );
        }
    }
}
