/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2005 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.ext.beans2;

import freemarker.template.TemplateHashModel;
import freemarker.template.TemplateObjectModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateModel;

import java.util.ResourceBundle;
import java.io.Serializable;

/**
 * @author Nicholas Cull
 * @version $Id: ResourceBundleWrapper.java 1170 2005-10-10 12:46:48Z run2000 $
 * @since 1.9
 */
public class ResourceBundleWrapper implements ObjectWrapper, TemplateHashModel,
        TemplateObjectModel, Serializable {

    /** Serialization UUID for this class */
    private static final long serialVersionUID = -8379991195053235923L;

    private ResourceBundle object;

    public ResourceBundleWrapper() {
    }

    public ResourceBundleWrapper( ResourceBundle object ) {
        this.object = object;
    }

    public void setObject( Object object ) {
        this.object = (ResourceBundle)object;
    }

    /**
     * Return the underlying object to the reflection mechanism in the
     * <code>freemarker.ext.beans</code> package. Any variables, methods
     * or properties can be called directly via reflection.</p>
     *
     * @return the underlying object for this template model
     * @throws freemarker.template.TemplateModelException
     *          the object could not be returned
     */
    public Object getAsObject() throws TemplateModelException {
        return object;
    }

    /**
     * Is the resource bundle empty or null?
     *
     * @return <code>true</code> if this object is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return (object == null) || (object.getKeys().hasMoreElements());
    }

    /**
     * Gets a value from the resource bundle.
     *
     * @param key the name by which the <code>TemplateModel</code>
     *            is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     *         or <code>null</code> if not found.
     */
    public TemplateModel get( String key ) throws TemplateModelException {
        return Wrapper.wrap( object.getObject( key ));
    }

    /**
     * Creates and returns a copy of this object.
     *
     * @return a clone of this instance.
     * @throws RuntimeException the clone operation was not successful
     * @throws OutOfMemoryError if there is not enough memory.
     * @see Cloneable
     */
    public Object clone() {
        try {
            return super.clone();
        } catch( CloneNotSupportedException e ) {
            throw new RuntimeException( "Clone method threw an exception: " + e.getMessage() );
        }
    }
}
