/*
 * ====================================================================
 *
 * Copyright (c) 2000 Attila Szegedi.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes the Expose library
 *        (http://www.szegedi.org/expose)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "Expose" and "Attila Szegedi" must not be used to endorse
 *    or promote products derived from this software without prior written
 *    permission. For written permission, please contact expose@szegedi.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 */

package freemarker.ext.servlet;

import freemarker.ext.beans2.Wrapper;
import freemarker.template.TemplateHashModel;
import freemarker.template.TemplateModel;

import javax.servlet.*;

/**
 * TemplateHashModel wrapper for <code>ServletContext</code> attributes.
 *
 * @author Attila Szegedi, attila@szegedi.org
 * @version $Id: ServletContextHashModel.java 1173 2005-10-10 12:55:05Z run2000 $
 */
public final class ServletContextHashModel implements TemplateHashModel
{
	private ServletContext servletctx;

    /**
     * Construct a new ServletContextHashModel.
     *
     * @param servletctx the servlet request to be adapted
     */
	public ServletContextHashModel(ServletContext servletctx)
	{
		this.servletctx = servletctx;
	}

    /**
     * Retrieve an attribute from the servlet context.
     *
     * @param key the name of the attribute to be retrieved
     * @return a <code>TemplateModel</code> wrapping the value we're interested in
     */
	public TemplateModel get(String key)
	{
		return Wrapper.wrap(servletctx.getAttribute(key));
	}

    /**
     * Do we have any attributes in the servlet context?
     *
     * @return <code>true</code> if there are no attributes, otherwise <code>false</code>
     */
	public boolean isEmpty()
	{
		return !servletctx.getAttributeNames().hasMoreElements();
	}
}
