/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.Template;
import freemarker.template.cache.Cache;
import java.io.IOException;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;

/**
 * Thread for accessing the cache for a set period of time, then exiting.  This
 * is used as part of the {@link TestCacheThreaded} test case.
 *
 * @author  <a href="mailto:run2000@users.sourceforge.net">Nicholas Cull</a>
 * @version $Id: CacheThread2.java 1003 2004-10-16 14:54:58Z run2000 $
 * @see CacheThread
 * @see CacheThread3
 * @see CacheThread4
 * @see CacheThread5
 * @see TestCacheThreaded
 */
public final class CacheThread2 implements Runnable {
    private final Cache cCache;
    private final long nPeriod;
    private long nAccesses;

    /** Creates new CacheThread. */
    public CacheThread2(long nPeriod, Cache cCache) {
        this.nPeriod = nPeriod;
        this.cCache = cCache;
        nAccesses = 0;
    }

    /**
     * Run the test for a given period of time.
     */
    public void run() {
        long nTime = System.currentTimeMillis();
        Template cItem;
        ByteArrayOutputStream cByteOut = new ByteArrayOutputStream();
        OutputStreamWriter cOut = new OutputStreamWriter( cByteOut );
        int nSize = 0;

        while( System.currentTimeMillis() < nTime + nPeriod ) {
            cByteOut.reset();
            cItem = (Template)cCache.getItem( "template/test-compress.html", "template" );
            if( cItem == null ) {
                System.out.println( "Null returned." );
            }
            try {
                cItem.process( cOut );
                cOut.flush();
            } catch (IOException e) {
                System.out.println( "An IOException was caught (2):" );
                e.printStackTrace();
            }

            if( nSize != cByteOut.size() ) {
                nSize = cByteOut.size();
                System.out.println( "Buffer length (2): " + Integer.toString( nSize ));
            }
            nAccesses++;
        }
        System.out.println( "Number of (2) accesses processed: " + nAccesses );
    }
}
