/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.misc.ExtendedHash;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import junit.framework.*;

/**
 * <p>Test class for testing the {@link freemarker.ext.misc.ExtendedHash}
 * template model. Runs through the special hash keys to see what comes out
 * the other end.</p>
 *
 * <p>This test could be problematic, since it assumes a particular ordering
 * for keysets and values from a hash, which are ultimately
 * dependant on the implementation of the underlying JVM class library.</p>
 *
 * @version $Id: TestExtendedHash.java 1128 2005-10-04 11:36:12Z run2000 $
 */
public final class TestExtendedHash extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestExtendedHash( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-exthash.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));

        ExtendedHash hash = new ExtendedHash();

        hash.put( "aardvark", "one" );
        hash.put( "kiwi", "two" );
        hash.put( "gecko", "three" );
        hash.put( "cat", "four" );
        hash.put( "dog", "five" );
        hash.put( "elephant", "six" );
        hash.put( "squirrel", "seven" );
        hash.put( "zebra", "eight" );

        modelRoot.put( "animals", hash );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringInputSource( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestExtendedHash( "test-exthash.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
