/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.format.NumberFormat;
import freemarker.ext.format.MessageFormat;
import freemarker.ext.format.DateFormat;
import freemarker.ext.beans2.Wrapper;

import java.io.IOException;
import java.io.StringWriter;
import java.math.BigDecimal;
import java.util.Date;

/**
 * Test class for testing the formatter classes in the
 * <code>freemarker.ext.format</code> package.
 *
 * @version $Id: TestFormat.java 1181 2005-10-11 12:13:54Z run2000 $
 */
public final class TestFormat extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestFormat( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() throws TemplateModelException {
        setUpFiles( "test-format.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));
        modelRoot.put("numberFormat", NumberFormat.getInstance());
        modelRoot.put("messageFormat", MessageFormat.getInstance());
        modelRoot.put("dateFormat", DateFormat.getInstance());

        modelRoot.put( "test1", new FastNumber( 42 ));
        modelRoot.put( "test2", Wrapper.wrap( new Long( 50000 )));
        modelRoot.put( "test3", Wrapper.wrap( new Integer( 50000 )));
        modelRoot.put( "test4", Wrapper.wrap( new Double( 3.14159 )));
        modelRoot.put( "test5", Wrapper.wrap( new BigDecimal( "3.14159" )));

        modelRoot.put( "test7", Wrapper.wrap( new Date( 12345678901234L )));
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringInputSource( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestFormat( "test-format.html" );

        cTest.run();
    }
}
