/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import java.io.IOException;
import java.io.StringWriter;
import junit.framework.*;

/**
 * Test class for testing {@link freemarker.template.cache.LocalizedFileRetriever}.
 *
 * @version $Id: TestLocalization.java 1095 2005-09-05 13:08:40Z run2000 $
 */
public final class TestLocalization extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestLocalization(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-local.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put( "message", new FastScalar( "Hello, world!" ));

    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        FileTemplateCache cCache;
        Template cTemplate;
        StringWriter cWriter = new StringWriter();
        freemarker.template.cache.LocalizedFileRetriever cRetriever;

        cRetriever = new freemarker.template.cache.LocalizedFileRetriever(
            getTestcasePath() + "/template" );

        cRetriever.setLocale( new java.util.Locale( "en", "AU" ));

        cCache = new FileTemplateCache();
        cCache.setRetriever( cRetriever );
        cCache.setLoadingPolicy( FileTemplateCache.Strategy.PRELOAD );

        cTemplate = (Template)cCache.getItem( "test-local.html" );
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);
        cCache.stopAutoUpdate();

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestLocalization( "test-local.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}