/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.misc.Log4jExceptionListener;
import java.io.*;
import org.apache.log4j.*;
import junit.framework.*;

/**
 * Performs a simple test on the {@link freemarker.ext.misc.Log4jExceptionListener}
 * class to see whether Log4j works correctly with it.
 *
 * @version $Id: TestLog4jExceptionHandler.java 1128 2005-10-04 11:36:12Z run2000 $
 */
public final class TestLog4jExceptionHandler extends AbstractTestCase {
    private FastHash modelRoot;
    private TemplateEventAdapter eventAdapter;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param name the name of the test
     */
    public TestLog4jExceptionHandler( String name ) {
        super( name );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        eventAdapter = new TemplateEventAdapter();
        eventAdapter.addTemplateExceptionListener( new Log4jExceptionListener() );

        Category cLog4jCat = Category.getInstance( "freemarker" );
        cLog4jCat.setPriority( Priority.INFO );

        setUpFiles( "test-logging.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put( "message", new FastScalar( "Hello, world!" ));

    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws Exception {
        StringWriter cWriter = new StringWriter();
        StringWriter cLogWriter = new StringWriter();
        Category cLog4jCat = Category.getInstance( "freemarker" );
        Template cTemplate;

        cTemplate = new Template( new StringInputSource( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        cLog4jCat.addAppender( new WriterAppender(
                new PatternLayout("%-5p [%c]: %m<br />%n"), cLogWriter ));

        // Process the template.
        cTemplate.process( modelRoot, cWriter, eventAdapter );

        String results = cWriter.toString() + cLogWriter.toString();
        showTestResults( m_aReferenceText, results );
    }

    /**
     * Main method for running the test case.
     *
     * @param args the command line arguments
     */
    public static void main( String args[] ) throws Exception {
        AbstractTestCase cTest = new TestLog4jExceptionHandler( "test-logging.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }

}
