/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import junit.framework.*;

/**
 * Test class for testing FM-Classic's &lt;noparse&gt; tag. Runs through
 * a series of tests to see what happens under stress.
 *
 * @version $Id: TestNoParse.java 1128 2005-10-04 11:36:12Z run2000 $
 */
public final class TestNoParse extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestNoParse( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-noparse.html" );

        modelRoot = new FastHash();
        modelRoot.put( "message", new FastScalar( "Hello, world!" ));
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringInputSource( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestNoParse( "test-noparse.html" );
        TestResult cResult = new TestResult();

        cTest.run( cResult );
    }
}
