/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;

import freemarker.template.*;

/**
 * Test parsing and operator precedence rules for numerics in FM-Classic.
 *
 * @version $Id: TestNumerics.java 1128 2005-10-04 11:36:12Z run2000 $
 * @author run2000
 */
public final class TestNumerics extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that takes a name for the test being performed.
     *
     * @param aTestName the name of the test
     */
    public TestNumerics( String aTestName ) {
        super( aTestName );
    }

    protected void setUp() throws Exception {
        setUpFiles( "test-numerics.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));

        FastHash numericModel = new FastHash();
        numericModel.put( "one", new FastNumber( 1 ));
        numericModel.put( "two", new FastNumber( 2 ));
        numericModel.put( "three", new FastNumber( 3 ));
        numericModel.put( "four", new FastNumber( 4 ));
        numericModel.put( "five", new FastNumber( 5 ));
        numericModel.put( "six", new FastNumber( 6 ));
        numericModel.put( "seven", new FastNumber( 7 ));
        numericModel.put( "eight", new FastNumber( 8 ));
        numericModel.put( "nine", new FastNumber( 9 ));
        numericModel.put( "ten", new FastNumber( 10 ));

        modelRoot.put( "numbers", numericModel );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringInputSource( m_aTemplateText ));

        // Process the template.
        cTemplate.process( modelRoot, cWriter );
        //System.out.println( cTemplate.toString() );

        showTestResults( m_aReferenceText, cWriter.toString() );
    }


    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestNumerics( "test-numerics.html" );

        cTest.run();
    }
}
