/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.testcase.models.SortedHash;
import freemarker.ext.misc.CollectionSize;
import freemarker.ext.misc.HashKeys;
import freemarker.ext.misc.HashValues;

import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;

import junit.framework.*;

/**
 * Test class for testing FM-Classic's TemplateObjectModel. In particular,
 * tests the CollectionSize, HashKeys, and HashValues methods that depend on
 * it.
 *
 * @version $Id: TestObjectModel.java 1128 2005-10-04 11:36:12Z run2000 $
 */
public final class TestObjectModel extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestObjectModel( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-objectmodel.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar( "Hello, world!" ));
        modelRoot.put("testHash", new SortedHash());
        modelRoot.put("size", CollectionSize.getInstance());
        modelRoot.put("keys", HashKeys.getInstance());
        modelRoot.put("values", HashValues.getInstance());

    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringInputSource( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestObjectModel( "test-objectmodel.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
