/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.misc.*;
import freemarker.testcase.models.*;

import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;

/**
 * Test class for testing the type evaluation classes in the
 * <code>freemarker.ext.misc</code> package.
 *
 * @version $Id: TestTypes.java 1128 2005-10-04 11:36:12Z run2000 $
 */
public final class TestTypes extends AbstractTestCase {
    private FastHash modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestTypes( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() throws TemplateModelException {
        setUpFiles( "test-types.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));
        modelRoot.put("isHash", IsHash.getInstance());
        modelRoot.put("isIndexed", IsIndexed.getInstance());
        modelRoot.put("isList", IsList.getInstance());
        modelRoot.put("isMethod", IsMethod.getInstance());
        modelRoot.put("isNumber", IsNumber.getInstance());
        modelRoot.put("isScalar", IsScalar.getInstance());
        modelRoot.put("isTransform", IsTransform.getInstance());

        modelRoot.put( "test1", new FastScalar("test1"));
        modelRoot.put( "test2", new FastNumber( 42 ));
        modelRoot.put( "test3", new FastList());
        modelRoot.put( "test4", new FastHash());
        modelRoot.put( "test5", Perl5Substitute.getInstance());
        modelRoot.put( "test6", CompressWhitespace.getInstance());
        modelRoot.put( "test7", new ListModel1());
        modelRoot.put( "test9", new MultiModel1());
        modelRoot.put( "test10", IndexedModel1.getInstance());
        modelRoot.put( "test11", new ListModel2());
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringInputSource( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestTypes( "test-types.html" );

        cTest.run();
    }
}
