/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.testcase.models;

import freemarker.template.TemplateIndexedModel;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateModel;
import freemarker.template.FastNumber;

/**
 * A trivial implementation of the <code>TemplateIndexedModel</code>
 * interface.
 *
 * @author Nicholas Cull
 * @version $Id: IndexedModel1.java 1003 2004-10-16 14:54:58Z run2000 $
 */
public class IndexedModel1 implements TemplateIndexedModel {

    private static final IndexedModel1 instance = new IndexedModel1();

    /** Private constructor, to indicate this is a singleton. */
    private IndexedModel1() {
    }

    /**
     * Get the singleton instance of this class.
     *
     * @return a new object of this class
     */
    public static IndexedModel1 getInstance() {
        return instance;
    }

    /**
     * Is the object empty?
     *
     * @return <code>true</code> if this object is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

    /**
     * Get the value corresponding to the given index. Traditionally this would
     * correspond to an index into an array, or similar structure, such as a
     * <code>java.util.Vector</code>.
     *
     * @param index the index of the underlying value we're interested in
     * @return a <code>TemplateModel</code> representing the value for the given index
     * @throws TemplateModelException the value could not be determined, possibly
     * due to an index out-of-bounds, or an otherwise undefined value
     */
    public TemplateModel getAtIndex( long index ) throws TemplateModelException {
        return new FastNumber( index * 2 );
    }
}
