/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import java.util.ArrayList;
import java.util.List;

import freemarker.template.*;

/**
 * A simple list model for testing the list iterator functionality. This
 * implements the old {@link TemplateListModel} interface to test
 * backward compatibility.
 *
 * @author Nicholas Cull
 * @version $Id: ListModel2.java 1003 2004-10-16 14:54:58Z run2000 $
 */
public final class ListModel2 implements TemplateListModel, TemplateHashModel {
    private List<String> items;
    private int currentItem;

    /** Default constructor that creates a simple list. */
    public ListModel2() {
        items = new ArrayList<String>(5);
        items.add( "one" );
        items.add( "two" );
        items.add( "three" );
        items.add( "four" );
        items.add( "five" );
    }

    /**
     * Is the model empty?
     * @return <code>true</code> if the list is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() {
        return items.isEmpty();
    }

    /**
     * Are there any more elements?
     * @return <code>true</code> if there are more elements, otherwise
     * <code>false</code>
     */
    public boolean hasNext() {
        return currentItem < items.size();
    }

    /**
     * Retrieve the next item in the list.
     * @return the next item in the list
     */
    public TemplateModel next() {
        return new FastScalar( items.get( currentItem++ ));
    }

    /**
     * Rewind the current item to the beginning of the list.
     */
    public void rewind() {
        currentItem = 0;
    }

    /**
     * Is the current item at the beginning of the list?
     * @return <code>true</code> if we are at the beginning of the list,
     * otherwise <code>false</code>
     */
    public boolean isRewound() {
        return currentItem == 0;
    }

    /**
     * Retrieve an item at the given index
     * @param index the index of the item to be retrieved
     * @return the item at the specified index
     */
    public TemplateModel get( int index ) {
        return new FastScalar( items.get( index ));
    }

    /**
     * Implement special keys to retrieve the size of the list and the index
     * of the current item.
     * @param key the name of the value to be retrieved
     * @return the named value, or <code>null</code>
     */
    public TemplateModel get( String key ) throws TemplateModelException {
        if( "item".equals(key)) {
            return new FastNumber( currentItem );
        } else if( "size".equals(key)) {
            return new FastNumber( items.size() );
        }
        return null;
    }
}
