/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import freemarker.template.TemplateMethodModel2;
import freemarker.template.TemplateModelException;
import freemarker.template.TemplateModel;

import java.util.List;

/**
 * Simple method model for testing the chaining of method models.
 *
 * @version $Id: MethodModel1.java 1014 2004-10-18 07:18:12Z run2000 $
 */
public class MethodModel1 implements TemplateMethodModel2 {

    /**
     * Is the object empty?
     *
     * @return <code>true</code> if this object is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

    /**
     * Executes a method call. Arguments are passed as a <code>List</code> of
     * {@link freemarker.template.TemplateModel} objects.
     *
     * @param arguments a <code>List</code> of <code>TemplateModel</code> objects
     * containing the values of the arguments passed to the method.
     * @return the <code>TemplateModel</code> produced by the method, or <code>null</code>.
     */
    public TemplateModel exec(List<TemplateModel> arguments) throws TemplateModelException {

        if( arguments.size() == 0 ) {
            throw new TemplateModelException(
                    "At least one argument must be supplied to MethodModel1" );
        }
        return arguments.get(0);
    }
}
