/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import freemarker.template.*;
import java.util.List;
import java.util.Iterator;

/**
 * Testcase to see how FM-Classic deals with multiple Template models.
 *
 * @version $Id: MultiModel2.java 1003 2004-10-16 14:54:58Z run2000 $
 * @see MultiModel1
 * @see MultiModel3
 * @see MultiModel4
 * @see MultiModel5
 */
public final class MultiModel2 implements TemplateScalarModel, TemplateMethodModel {

    /** Creates new MultiModel2. */
    public MultiModel2() {
    }

    /**
     * Returns the scalar's value as a <code>String</code>.
     *
     * @return the <code>String</code> value of this scalar.
     */
    public String getAsString() throws TemplateModelException {
        return "Model2 is alive!";
    }

    /**
     * Is the model empty?
     *
     * @return <code>false</code> to indicate the model is not empty
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

    /**
     * Executes a method call.
     *
     * @param arguments a <code>List</code> of <code>String</code> objects
     * containing the values of the arguments passed to the method.
     * @return the <code>TemplateModel</code> produced by the method,
     * or <code>null</code>.
     */
    public TemplateModel exec(List<String> arguments) throws TemplateModelException {
        StringBuffer  aResults = new StringBuffer( "Arguments are:<br />" );

        for( String item : arguments ) {
            aResults.append( item );
            aResults.append( "<br />" );
        }

        return new FastScalar( aResults.toString() );
    }
}
