/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2004 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import java.util.List;
import java.util.ArrayList;

import freemarker.template.*;

/**
 * Testcase to see how FM-Classic deals with multiple Template models.
 *
 * @version $Id: MultiModel4.java 1104 2005-09-08 11:40:41Z run2000 $
 * @see MultiModel1
 * @see MultiModel2
 * @see MultiModel3
 * @see MultiModel5
 */
public final class MultiModel4 implements TemplateListModel2, TemplateIndexedModel,
        TemplateHashModel {

    private FastList<?> m_cList;

    /** Creates new MultiModel4. */
    public MultiModel4() {
        List<FastScalar> list = new ArrayList<FastScalar>();
        list.add( new FastScalar("one"));
        m_cList = new FastList<FastScalar>( list );
    }

    /**
     * Retrieves an iterator to iterate over this list.
     *
     * @return an iterator to iterate over the current list.
     * @throws TemplateModelException the next item in the list can't be
     * retrieved, or no next item exists.
     */
    public TemplateIteratorModel templateIterator() throws TemplateModelException {
        return m_cList.templateIterator();
    }

    /**
     * Returns the used iterator to the list model.
     *
     * @param iterator the iterator to be returned to the object pool
     */
    public void releaseIterator(TemplateIteratorModel iterator) {
        m_cList.releaseIterator( iterator );
    }

    /**
     * Retrieves the specified item from the list.
     *
     * @param index the index of the item to be retrieved.
     * @return the specified index in the list.
     * @throws TemplateModelException the specified item in the list can't be
     * retrieved, or the index is out of bounds.
     */
    public TemplateModel getAtIndex(long index) throws TemplateModelException {
        return m_cList.getAtIndex( index );
    }

    /**
     * Is the model empty?
     *
     * @return <code>true</code> if the object is empty, otherwise <code>false</code>.
     */
    public boolean isEmpty() throws TemplateModelException {
        return m_cList.isEmpty();
    }

    /**
     * Gets the specified {@link freemarker.template.TemplateModel} from the hash.
     *
     * @param key the name by which the <code>TemplateModel</code>
     * is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     * or <code>null</code> if not found.
     */
    public TemplateModel get(String key) throws TemplateModelException {
        if( "size".equals(key)) {
            return new FastScalar( "Key size, not the listSize method." );
        } else {
            return null;
        }
    }
}
